import java.util.*;
import java.awt.*;

public class Missile {
	public static final double BSPEED = 8;
	public static final int MISSILE_WIDTH = 16;
	public static final int MISSILE_HEIGHT = 16;

	private int x, y;
	private Direction bDir = null;
	private TankWar tw;
	private boolean live = true;
	private Color color;
	
	public void setLive(boolean live) {
		this.live = live;
	}

	public boolean isLive() {
		return live;
	}

	Missile(int x, int y, Direction bDir) {
		this.x = x;
		this.y = y;
		this.bDir = bDir;
	}

	Missile(int x, int y, Direction bDir, Color color, TankWar tw) {
		this.x = x;
		this.y = y;
		this.bDir = bDir;
		this.tw = tw;
		this.color = color;
	}

	public void draw(Graphics g) {
		if (live == false) {
			if (tw.missiles.contains(this))
				tw.missiles.remove(this);
			else
				tw.enermyMissiles.remove(this);
		}

		Color c = g.getColor();
		if (tw.missiles.contains(this))
			g.setColor(this.getColor());
		else
			g.setColor(this.getColor());
		g.fillOval(x, y, Missile.MISSILE_WIDTH, Missile.MISSILE_HEIGHT);
		g.setColor(c);

		shoots();
	}

	public void shoots() {
		switch (bDir) {
		case L:
			x -= BSPEED;
			break;
		case LU:
			x -= BSPEED;
			y -= BSPEED;
			break;
		case U:
			y -= BSPEED;
			break;
		case RU:
			y -= BSPEED;
			x += BSPEED;
			break;
		case R:
			x += BSPEED;
			break;
		case RD:
			x += BSPEED;
			y += BSPEED;
			break;
		case D:
			y += BSPEED;
			break;
		case LD:
			y += BSPEED;
			x -= BSPEED;
			break;
		}
		if (x < 0 || y < 0 || x > TankWar.WINDOW_WIDTH|| y > TankWar.WINDOW_HEIGHT)
			live = false;
	}

	public Point getPoint() {
		Point p = new Point();
		p.setLocation(x, y);
		return p;
	}

	public Rectangle getRec() {
		return new Rectangle(x, y, Missile.MISSILE_WIDTH,
				Missile.MISSILE_HEIGHT);
	}

	public boolean hitClient(Tank c) {
		c.eatBlood(tw.blood);
		if (tw.enermyMissiles.contains(this) && c.isLive()) {
			if (this.getRec().intersects(c.getRec())) {
				c.life--;
				if (c.life == 0) {
					c.setLive(false);
				}
				this.setLive(false);
				return true;
			}
		}
		return false;
	}

	public boolean wallCrashed(Wall w) {
		if (this.getRec().intersects(w.getRec())) {
			this.setLive(false);
			return true;
		}
		return false;
	}
	
	public void setColor(Color col){
		this.color = col;
	}
	
	public Color getColor(){
		return color;
	}

}
